@@ -69,7 +69,7 @@ class CfnDataCatalog(
             tags=tags,
         )
 
-        jsii.create(CfnDataCatalog, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -311,7 +311,7 @@ class CfnNamedQuery(
             work_group=work_group,
         )
 
-        jsii.create(CfnNamedQuery, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -517,6 +517,215 @@ class CfnNamedQueryProps:
         )
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
+class CfnPreparedStatement(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-athena.CfnPreparedStatement",
+):
+    '''A CloudFormation ``AWS::Athena::PreparedStatement``.
+
+    :cloudformationResource: AWS::Athena::PreparedStatement
+    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html
+    '''
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: builtins.str,
+        *,
+        query_statement: builtins.str,
+        statement_name: builtins.str,
+        work_group: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''Create a new ``AWS::Athena::PreparedStatement``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param query_statement: ``AWS::Athena::PreparedStatement.QueryStatement``.
+        :param statement_name: ``AWS::Athena::PreparedStatement.StatementName``.
+        :param work_group: ``AWS::Athena::PreparedStatement.WorkGroup``.
+        :param description: ``AWS::Athena::PreparedStatement.Description``.
+        '''
+        props = CfnPreparedStatementProps(
+            query_statement=query_statement,
+            statement_name=statement_name,
+            work_group=work_group,
+            description=description,
+        )
+
+        jsii.create(self.__class__, self, [scope, id, props])
+
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        '''Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+        '''
+        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(
+        self,
+        props: typing.Mapping[builtins.str, typing.Any],
+    ) -> typing.Mapping[builtins.str, typing.Any]:
+        '''
+        :param props: -
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
+
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="queryStatement")
+    def query_statement(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.QueryStatement``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-querystatement
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "queryStatement"))
+
+    @query_statement.setter
+    def query_statement(self, value: builtins.str) -> None:
+        jsii.set(self, "queryStatement", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="statementName")
+    def statement_name(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.StatementName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-statementname
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "statementName"))
+
+    @statement_name.setter
+    def statement_name(self, value: builtins.str) -> None:
+        jsii.set(self, "statementName", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="workGroup")
+    def work_group(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.WorkGroup``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-workgroup
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "workGroup"))
+
+    @work_group.setter
+    def work_group(self, value: builtins.str) -> None:
+        jsii.set(self, "workGroup", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[builtins.str]:
+        '''``AWS::Athena::PreparedStatement.Description``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-description
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
+
+    @description.setter
+    def description(self, value: typing.Optional[builtins.str]) -> None:
+        jsii.set(self, "description", value)
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-athena.CfnPreparedStatementProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "query_statement": "queryStatement",
+        "statement_name": "statementName",
+        "work_group": "workGroup",
+        "description": "description",
+    },
+)
+class CfnPreparedStatementProps:
+    def __init__(
+        self,
+        *,
+        query_statement: builtins.str,
+        statement_name: builtins.str,
+        work_group: builtins.str,
+        description: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''Properties for defining a ``AWS::Athena::PreparedStatement``.
+
+        :param query_statement: ``AWS::Athena::PreparedStatement.QueryStatement``.
+        :param statement_name: ``AWS::Athena::PreparedStatement.StatementName``.
+        :param work_group: ``AWS::Athena::PreparedStatement.WorkGroup``.
+        :param description: ``AWS::Athena::PreparedStatement.Description``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "query_statement": query_statement,
+            "statement_name": statement_name,
+            "work_group": work_group,
+        }
+        if description is not None:
+            self._values["description"] = description
+
+    @builtins.property
+    def query_statement(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.QueryStatement``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-querystatement
+        '''
+        result = self._values.get("query_statement")
+        assert result is not None, "Required property 'query_statement' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def statement_name(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.StatementName``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-statementname
+        '''
+        result = self._values.get("statement_name")
+        assert result is not None, "Required property 'statement_name' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def work_group(self) -> builtins.str:
+        '''``AWS::Athena::PreparedStatement.WorkGroup``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-workgroup
+        '''
+        result = self._values.get("work_group")
+        assert result is not None, "Required property 'work_group' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def description(self) -> typing.Optional[builtins.str]:
+        '''``AWS::Athena::PreparedStatement.Description``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-athena-preparedstatement.html#cfn-athena-preparedstatement-description
+        '''
+        result = self._values.get("description")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "CfnPreparedStatementProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnWorkGroup(
     aws_cdk.core.CfnResource,
@@ -564,7 +773,7 @@ class CfnWorkGroup(
             work_group_configuration_updates=work_group_configuration_updates,
         )
 
-        jsii.create(CfnWorkGroup, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -608,6 +817,16 @@ class CfnWorkGroup(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrWorkGroupConfigurationEngineVersionEffectiveEngineVersion"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="attrWorkGroupConfigurationUpdatesEngineVersionEffectiveEngineVersion")
+    def attr_work_group_configuration_updates_engine_version_effective_engine_version(
+        self,
+    ) -> builtins.str:
+        '''
+        :cloudformationAttribute: WorkGroupConfigurationUpdates.EngineVersion.EffectiveEngineVersion
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "attrWorkGroupConfigurationUpdatesEngineVersionEffectiveEngineVersion"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
@@ -1374,6 +1593,8 @@ __all__ = [
     "CfnDataCatalogProps",
     "CfnNamedQuery",
     "CfnNamedQueryProps",
+    "CfnPreparedStatement",
+    "CfnPreparedStatementProps",
     "CfnWorkGroup",
     "CfnWorkGroupProps",
 ]
